/**
* Title: 		 SimpleMapper
* Description:	 Dummy mapper updating a JSON like payload.
* Copyright:     Copyright (c) 2015
* Company:       Morpheus Quality Technologies
* Creation date: 22-06-2015
* Last modified: 22-06-2015
* @author 		 Stefano Adriani
* @version 		 1.0
*/

package mappers;

import org.mule.api.MuleEventContext;
import org.mule.api.lifecycle.Callable;

/**
* Dummy data mapper manipulating a JSON payload, wrapped by a <code>JsonDTO</code> class. 
*/
public class SimpleMapper implements Callable {
	
	/** If <code>true</code> some detailed messages are printed on STDOUT.									*/
	protected static 		boolean							verbose		 		= false;

	/** Beginning of each logging message produced by this class.											*/
	protected static 		String							leadingName 		= "SimpleMapper - ";
	 
	/**
	* Main method, invoked when the component receives the payload.
	*
	* @param eventContext the current Mule Event Context, passed automatically by the container
	*/
	@Override
	public Object onCall(MuleEventContext eventContext)	throws Exception {
		
		Object newPayload = null;
		
		try {

			Object payload	= eventContext.getMessage().getPayload();
			
			if (verbose) {
				System.out.println(leadingName + "Payload: " 		+ payload);
				System.out.println(leadingName + "Payload class: "  + payload.getClass().getName());
			}
			
			// Dummy custom mapping example
			if (payload instanceof JsonDTO) {
				// Logging input DTO
				System.out.println(leadingName + "Name    : " 	+ ((JsonDTO) payload).getName() 	);
				System.out.println(leadingName + "Surname : " 	+ ((JsonDTO) payload).getSurname() 	);
				System.out.println(leadingName + "Age     : " 	+ ((JsonDTO) payload).getAge()	 	);
				// Producing output DTO
				JsonDTO dto = new JsonDTO();
				dto.setName		( ((JsonDTO) payload).getName() );
				dto.setSurname	( ((JsonDTO) payload).getSurname() );
				dto.setAge		( 45 );
				newPayload = dto;
			} else {
				System.out.println(leadingName + "Unexpected payload class: " + payload);
			}
		
    	} catch(Exception e) {
    		if (verbose) System.out.println(leadingName + "Exception: " + e);
        	e.printStackTrace();
        }
		
        return newPayload;
    }

} // End of class